import { Plugin, IPlugin, PluginRequest, Profile } from './plugin';
interface PluginMap {
    [name: string]: IPlugin;
}
interface ExposedMethods {
    [name: string]: {
        [key: string]: (requestInfo: PluginRequest, ...payload: any[]) => Promise<any>;
    };
}
interface ExposedEvents {
    [recipient: string]: {
        [eventName: string]: (...payload: any[]) => void;
    };
}
interface EventRecord {
    [eventName: string]: string[];
}
interface PluginEngineSettings {
    autoActivate: boolean;
}
interface PermissionHandler {
    askPermission: (from: Profile, to: Profile) => Promise<boolean>;
}
declare abstract class AbstractPluginEngine {
    protected methods: ExposedMethods;
    protected events: ExposedEvents;
    protected eventsRecord: EventRecord;
    abstract permissionHandler: PermissionHandler;
    abstract register(plugins: IPlugin | IPlugin[]): void;
    abstract activate(names: string | string[]): void;
    abstract deactivate(names: string | string[]): void;
    abstract onRegistration(plugin: IPlugin): void;
    abstract onActivation(plugin: IPlugin): void;
    abstract onDeactivation(plugin: IPlugin): void;
}
export declare abstract class PluginEngine extends AbstractPluginEngine {
    protected settings: PluginEngineSettings;
    protected plugins: PluginMap;
    protected methods: ExposedMethods;
    protected events: ExposedEvents;
    protected eventsRecord: EventRecord;
    abstract permissionHandler: PermissionHandler;
    constructor(plugins: Plugin[]);
    readonly actives: string[];
    private isRegistered;
    private isActive;
    register(plugins: IPlugin | IPlugin[]): void;
    private registerOne;
    /** Activate one or several plugins */
    activate(names: string | string[]): void;
    /** Activate one plugin */
    private activateOne;
    /** Deactivate one or several plugins */
    deactivate(names: string | string[]): void;
    /** Deactivate one plugin */
    deactivateOne(name: string): void;
    abstract onRegistration(plugin: IPlugin): void;
    abstract onActivation(plugin: IPlugin): void;
    abstract onDeactivation(plugin: IPlugin): void;
}
export {};
