export interface RequestParams {
    name: string;
    key: string;
    payload: any[];
}
export interface PluginRequest {
    from: string;
}
export interface Profile {
    name: string;
    methods: string[];
    permission?: boolean;
}
export interface IPlugin<P extends Profile = any> {
    name: string;
    profile: Profile;
    addRequest(request: PluginRequest, method: P['methods'][number], args: any[]): Promise<any>;
    on(name: string, key: string, cb: (payload: any[]) => void): void;
    call(name: string, key: string, payload: any[]): Promise<any>;
    emit(key: string, payload: any[]): void;
    activate(): void;
    deactivate(): void;
    onRegistation?(): void;
    onActivation?(): void;
    onDeactivation?(): void;
}
export declare abstract class Plugin implements IPlugin {
    profile: Profile;
    readonly name: string;
    protected requestQueue: Array<() => Promise<any>>;
    protected currentRequest: PluginRequest;
    onRegistation?(): void;
    onActivation?(): void;
    onDeactivation?(): void;
    constructor(profile: Profile);
    activate(): void;
    deactivate(): void;
    /** Call a method from this plugin */
    protected callPluginMethod(method: string, args: any[]): any;
    /** Add a request to the list of current requests */
    addRequest(request: PluginRequest, method: Profile['methods'][number], // Extract<keyof , string>,
    args: any[]): Promise<{}>;
    on(name: string, key: string, cb: (...payload: any[]) => void): void;
    call(name: string, key: string, ...payload: any[]): Promise<void>;
    emit(key: string, ...payload: any[]): void;
}
