import { Plugin, Profile } from './abstract';
interface HostProfile extends Profile {
    methods: ['addHost', 'removeHost', 'focus'];
}
interface ViewMap {
    [name: string]: Element;
}
export declare abstract class HostPlugin extends Plugin {
    profile: HostProfile;
    protected entities: ViewMap;
    protected active: string;
    constructor(profile: HostProfile);
    /** Display the view inside the host */
    focus(name: string): Promise<void>;
    /** Add the view of a plugin into the DOM */
    addView(name: string, view: Element): Promise<void>;
    /** Remove the plugin from the view from the DOM */
    removeView(name: string): Promise<void>;
    /** Use this function to add the view into the DOM */
    abstract onViewAdded(view: Element, name: string): void | Promise<void>;
    /** Use this function to remove the view from the DOM */
    abstract onViewRemoved(view: Element, name: string): void | Promise<void>;
    /** Use this function to change the current view display */
    abstract onFocus(view: Element, name: string): void | Promise<void>;
}
export {};
